<?php
/* This file is part of the wp-forecast plugin for wordpress */

/*  Copyright 2006  Hans Matzen  (email : webmaster at tuxlog.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// uri for location search
$LOC_URI="http://forecastfox.accuweather.com/adcbin/forecastfox/locate_city.asp?location=";

// location array and counter init
$loc=array();
$i=0;

// generic functions
require_once("functions.php");

//
// add menuitem to options menu
//
function wp_forecast_admin() 
{
    if (function_exists('add_options_page')) {
	add_options_page('WP-Forecast', 'WP-Forecast', 6, 
			 basename(__FILE__), 'admin_form');
    }
}

//
// delete cookie if parameters are changed, to make sure
// current data will be available with next call
//
function wp_forecast_admin_init() 
{
    if ( ($_SERVER['QUERY_STRING']=="page=wp-forecast-admin.php") && (isset($_POST['info_update']) ))
    {
        // delete cookie for old location
	setcookie("wp_forecast_cache",'', time() - 3600,"/wordpress/");
    }
}

//
// get the locationlist and return it in one long string
//
function get_loclist($uri,$loc)
{
    $url=$uri . urlencode($loc);
    $xml = fetchURL($url);
    
    return $xml;
}

//
// parse xml and extract locations as an array
// for later us in the admin form
//
function get_locations($xml)
{
    // start_element() - wird vom XML-Parser bei öffnenden Tags aufgerufen
    function s_element( $parser, $name, $attribute )
	{
	    // Umwandlungstabelle in den lokalen Scope holen
	    global $loc,$i;
	    if ($name == "LOCATION") {
		$loc[$i]=array();
		$loc[$i]['city'] = $attribute['CITY'];
		$loc[$i]['state'] = $attribute['STATE'];
		$loc[$i]['location'] = $attribute['LOCATION'];
		$i++;
	    }
	}
	    
    // end_element() - dummy function
    function e_element( $parser, $name ){}
    
    // Instanz des XML-Parsers erzeugen
    $parser = xml_parser_create();
    
    // Parameter des XML-Parsers setzen 
    xml_parser_set_option( $parser, XML_OPTION_CASE_FOLDING, true ); 
    
    // Handler für Elemente ( öffnende / schließende Tags ) setzen 
    xml_set_element_handler( $parser, "s_element", "e_element" ); 
    
    // Versuche zu parsen
    if( !xml_parse( $parser, $xml,true ) )
    {
	// Fehler -> Ausführung abbrechen
	die(  "XML Fehler: " . 
	      xml_error_string( xml_get_error_code( $parser ) ) . 
	      " in Zeile " .
	      xml_get_current_line_number( $parser )
	    );
    }
    
    // Vom XML-Parser belegten Speicher freigeben
    xml_parser_free( $parser );

    // und zurueckgeben
    return $loc;
}
    
//
// form to modify wp-forecast setup
// options in wp_option: wp-forecast-location, wp-forecast-refresh
//                       wp-forecast-metric,   wp-forecast-language
//                       wp-forecast-days
// the form also has a search function to search the wright location
//
function admin_form() {
    global $LOC_URI,$loc;

    // get options
    $location=get_option("wp-forecast-location");
    $refresh=get_option("wp-forecast-refresh"); 
    $metric=get_option("wp-forecast-metric"); 
    $language=get_option("wp-forecast-language");
    $days=get_option("wp-forecast-days");
    
    // if this is a POST call, save new values
    if (isset($_POST['info_update'])) {
	$upflag=false;
	
	if ($location != $_POST["location"]) {
	    $location =  $_POST["location"];
	    update_option("wp-forecast-location", $location);
	    $upflag=true;
	}
	
	if ($refresh != $_POST["refresh"]) {
	    $refresh =  $_POST["refresh"];
	    update_option("wp-forecast-refresh", $refresh);
	    $upflag=true;
	}
	
	if ($metric != $_POST["metric"]) {
	    $metric =  $_POST["metric"];
	    if ($metric=="") $metric="0";
	    update_option("wp-forecast-metric", $metric);
	    $upflag=true;
	}
	
	if ($language != $_POST["language"]) {
	    $language =  $_POST["language"];
	    update_option("wp-forecast-language", $language);
	    $upflag=true;
	}
	
	if ($days != $_POST["days"]) {
	    $days =  $_POST["days"];
	    update_option("wp-forecast-days", $days);
	    $upflag=true;
	}
	 
    ?><div class="updated"><p><strong><?php 
	   if ($upflag) 
	       _e('Settings successfully updated','Localization name');
	   else
	       _e('You have to change a field to update settings.');

    ?></strong></p></div><?php
	} 

    // if this is a POST call, search locations
    if (isset($_POST['search_loc'])) {
	$xml=get_loclist($LOC_URI,$_POST["searchloc"]);
	$xml=utf8_encode($xml);
	get_locations($xml);
    }

    // if this is a POST call, set location
    if (isset($_POST['set_loc'])) {
	$location=$_POST["newloc"];
    }
    
?>

	 <div class=wrap>
	 <form method="post">
	 <h2>WP-Forecast Setup</h2>
	 <fieldset name="set1">
	 <legend><?php _e('Parameters', 'Localization name') ?></legend><p>
	 <b>Location:</b>
	 <input name="location" type="text" size="30" maxlength="80" value="<?php echo $location ?>">
	 <?php if (isset($_POST['set_loc'])) { ?>
	       <b>Press Update options to save new location.</b>
         <?php } ?>
         <br><p>
	 <b>Refresh cache after</b>
         <input name="refresh" type="text" size="10" maxlength="6" value="<?php echo $refresh ?>">
         <b>secs.</b><br><p>
	 <input type="checkbox" name="metric" value="1" <?php if ($metric=="1") echo "checked"?>> <b>Use metric units</b>
	 <br><p>
         <b>Language: </b><select name="language" size="1">
	      <option value="en" <?php if ($language=="en") echo "selected"?>>english</option>
	      <option value="de" <?php if ($language=="de") echo "selected"?>>deutsch</option>
	 </select><br><p>
	 <b>Forecast days: </b><select name="days" size="1">
	      <option <?php if ($days=="1") echo "selected" ?>>1</option>
	      <option <?php if ($days=="2") echo "selected" ?>>2</option>
	      <option <?php if ($days=="3") echo "selected" ?>>3</option>
	      <option <?php if ($days=="4") echo "selected" ?>>4</option>
	      <option <?php if ($days=="5") echo "selected" ?>>5</option>
	      <option <?php if ($days=="6") echo "selected" ?>>6</option>
	      <option <?php if ($days=="7") echo "selected" ?>>7</option>
	      <option <?php if ($days=="8") echo "selected" ?>>8</option>
	      <option <?php if ($days=="9") echo "selected" ?>>9</option>
	 </select><br><p>
     </fieldset>

<div class="submit">
  <input type="submit" name="info_update" value="<?php
    _e('Update options', 'Localization name')
	?> »" /></div>
<hr>
     <fieldset name="set2">
	 <legend><?php _e('Search location', 'Localization name') ?></legend><p>
<?php
   if (count($loc)<=0) { 	 
       echo "<b>Searchterm:</b>\n";
       echo "<input name=\"searchloc\" type=\"text\" size=\"30\" maxlength=\"30\"><br><p>\n";
       if (isset($_POST['search_loc'])) { 
	   echo "No locations found.<p>";
       }
       echo "</fieldset>\n";
       echo "<div class=\"submit\">\n";
       echo "<input type=\"submit\" name=\"search_loc\" value=\"" ;
       echo _e('Search location', 'Localization name');
       echo " »\" />\n";
   } else {
       echo "<b>Search result: </b><select name=\"newloc\" size=\"1\">\n";
       foreach ($loc as $l) {
	   echo "<option value=\"".$l['location']."\">";
	   echo $l['city']."/".$l['state'];
	   echo "</option>\n";
       }
       echo "</select><br>Please select your city and press set location.<p>\n";
       echo "</fieldset>\n";
        echo "<div class=\"submit\">\n";
	echo "<input type=\"submit\" name=\"set_loc\" value=\"" ;
       echo  _e('Set location', 'Localization name');
       echo " »\" />\n";
   } ?>
 
  </div></form>
 </div><?php
}
?>
